@@ -17,6 +17,8 @@
 #define _GNU_SOURCE 1
 #define _POSIX_PTHREAD_SEMANTICS 1
 #define _TANDEM_SOURCE 1
+#define HAVE_INFINITY 1
+#define HAVE_NAN 1
 #define RUBY_SYMBOL_EXPORT_BEGIN _Pragma("GCC visibility push(default)")
 #define RUBY_SYMBOL_EXPORT_END _Pragma("GCC visibility pop")
 #define HAVE_LIBCRYPT 1
@@ -25,33 +27,36 @@
 #define HAVE__BOOL 1
 #define HAVE_STDBOOL_H 1
 #define HAVE_SYS_WAIT_H 1
+#define HAVE_A_OUT_H 1
+#define HAVE_GRP_H 1
+#define HAVE_FCNTL_H 1
+#define HAVE_FLOAT_H 1
+#define HAVE_LANGINFO_H 1
 #define HAVE_LIMITS_H 1
+#define HAVE_LOCALE_H 1
+#define HAVE_MALLOC_H 1
+#define HAVE_PWD_H 1
+#define HAVE_SYS_FCNTL_H 1
 #define HAVE_SYS_FILE_H 1
 #define HAVE_SYS_IOCTL_H 1
-#define HAVE_SYS_SYSCALL_H 1
-#define HAVE_FCNTL_H 1
-#define HAVE_SYS_FCNTL_H 1
+#define HAVE_SYS_PARAM_H 1
+#define HAVE_SYS_PRCTL_H 1
+#define HAVE_SYS_RESOURCE_H 1
 #define HAVE_SYS_SELECT_H 1
+#define HAVE_SYS_SENDFILE_H 1
+#define HAVE_SYS_SOCKET_H 1
+#define HAVE_SYS_SYSCALL_H 1
+#define HAVE_SYS_SYSMACROS_H 1
 #define HAVE_SYS_TIME_H 1
 #define HAVE_SYS_TIMES_H 1
-#define HAVE_SYS_PARAM_H 1
+#define HAVE_SYS_UIO_H 1
 #define HAVE_SYSCALL_H 1
-#define HAVE_PWD_H 1
-#define HAVE_GRP_H 1
-#define HAVE_A_OUT_H 1
-#define HAVE_UTIME_H 1
-#define HAVE_SYS_RESOURCE_H 1
-#define HAVE_FLOAT_H 1
-#define HAVE_UCONTEXT_H 1
-#define HAVE_LANGINFO_H 1
-#define HAVE_LOCALE_H 1
-#define HAVE_SYS_SENDFILE_H 1
 #define HAVE_TIME_H 1
-#define HAVE_SYS_SOCKET_H 1
-#define HAVE_SYS_PRCTL_H 1
-#define HAVE_MALLOC_H 1
+#define HAVE_UCONTEXT_H 1
+#define HAVE_UTIME_H 1
 #define HAVE_GMP_H 1
 #define HAVE_LIBGMP 1
+#define HAVE_TYPEOF 1
 #define HAVE_LONG_LONG 1
 #define HAVE_OFF_T 1
 #define SIZEOF_INT 4
@@ -66,6 +71,8 @@
 #define SIZEOF_DOUBLE 8
 #define SIZEOF_TIME_T 8
 #define SIZEOF_CLOCK_T 8
+#define PACKED_STRUCT(x) x __attribute__((packed))
+#define USE_UNALIGNED_MEMBER_ACCESS 1
 #define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
 #define SIGNEDNESS_OF_PID_T -1
@@ -117,17 +124,31 @@
 #define STRINGIZE(expr) STRINGIZE0(expr)
 #define HAVE_STDARG_PROTOTYPES 1
 #define HAVE_VA_ARGS_MACRO 1
-#define NORETURN(x) __attribute__ ((noreturn)) x
-#define DEPRECATED(x) __attribute__ ((deprecated)) x
-#define NOINLINE(x) __attribute__ ((noinline)) x
+#define CONSTFUNC(x) __attribute__ ((__const__)) x
+#define PUREFUNC(x) __attribute__ ((__pure__)) x
+#define NORETURN(x) __attribute__ ((__noreturn__)) x
+#define DEPRECATED(x) __attribute__ ((__deprecated__)) x
+#define DEPRECATED_BY(n,x) __attribute__ ((__deprecated__("by "#n))) x
+#define DEPRECATED_TYPE(mesg,x) __attribute__ ((__deprecated__ mesg)) x
+#define NOINLINE(x) __attribute__ ((__noinline__)) x
+#define ALWAYS_INLINE(x) __attribute__ ((__always_inline__)) x
+#define WARN_UNUSED_RESULT(x) __attribute__ ((__warn_unused_result__)) x
+#define MAYBE_UNUSED(x) __attribute__ ((__unused__)) x
+#define ERRORFUNC(mesg,x) __attribute__ ((__error__ mesg)) x
+#define WARNINGFUNC(mesg,x) __attribute__ ((__warning__ mesg)) x
+#define WEAK(x) __attribute__ ((__weak__)) x
+#define HAVE_FUNC_WEAK 1
+#define FUNC_UNOPTIMIZED(x) __attribute__ ((__optimize__("O0"))) x
+#define FUNC_MINIMIZED(x) __attribute__ ((__optimize__("-Os","-fomit-frame-pointer"))) x
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_SYNC_BUILTINS 1
 #define UNREACHABLE __builtin_unreachable()
-#define RUBY_FUNC_EXPORTED __attribute__ ((visibility("default"))) extern
+#define RUBY_FUNC_EXPORTED __attribute__ ((__visibility__("default"))) extern
 #define RUBY_FUNCTION_NAME_STRING __func__
+#define ENUM_OVER_INT 1
 #define HAVE_DECL_SYS_NERR 1
 #define HAVE_DECL_GETENV 1
 #define SIZEOF_SIZE_T 8
@@ -140,8 +161,9 @@
 #define HAVE_ST_BLOCKS 1
 #define HAVE_STRUCT_STAT_ST_RDEV 1
 #define HAVE_ST_RDEV 1
-#define SIZEOF_STRUCT_STAT_ST_SIZE SIZEOF_LONG
-#define SIZEOF_STRUCT_STAT_ST_BLOCKS SIZEOF_LONG
+#define SIZEOF_STRUCT_STAT_ST_SIZE SIZEOF_OFF_T
+#define SIZEOF_STRUCT_STAT_ST_BLOCKS SIZEOF_OFF_T
+#define SIZEOF_STRUCT_STAT_ST_INO SIZEOF_LONG
 #define HAVE_STRUCT_STAT_ST_ATIM 1
 #define HAVE_STRUCT_STAT_ST_MTIM 1
 #define HAVE_STRUCT_STAT_ST_CTIM 1
@@ -172,7 +194,7 @@
 #define SIZEOF_INT128_T SIZEOF___INT128
 #define HAVE_UINT128_T 1
 #define uint128_t unsigned __int128
-#define SIZEOF_UINT128_T SIZEOF_UNSIGNED___INT128
+#define SIZEOF_UINT128_T SIZEOF___INT128
 #define HAVE_INTPTR_T 1
 #define SIZEOF_INTPTR_T 8
 #define HAVE_UINTPTR_T 1
@@ -184,32 +206,42 @@
 #define RETSIGTYPE void
 #define HAVE_ALLOCA_H 1
 #define HAVE_ALLOCA 1
-#define HAVE_DUP2 1
-#define HAVE_MEMMOVE 1
-#define HAVE_STRERROR 1
-#define HAVE_STRCHR 1
-#define HAVE_STRSTR 1
-#define HAVE_CRYPT 1
-#define HAVE_FLOCK 1
-#define HAVE_ISNAN 1
-#define HAVE_FINITE 1
-#define HAVE_ISINF 1
-#define HAVE_HYPOT 1
 #define HAVE_ACOSH 1
-#define HAVE_ERF 1
-#define HAVE_TGAMMA 1
-#define HAVE_LGAMMA_R 1
 #define HAVE_CBRT 1
+#define HAVE_CRYPT 1
+#define HAVE_DUP2 1
+#define HAVE_ERF 1
+#define HAVE_EXPLICIT_BZERO 1
 #define HAVE_FFS 1
+#define HAVE_FINITE 1
+#define HAVE_FLOCK 1
+#define HAVE_HYPOT 1
+#define HAVE_ISINF 1
+#define HAVE_ISNAN 1
+#define HAVE_LGAMMA_R 1
+#define HAVE_MEMMOVE 1
+#define HAVE_NEXTAFTER 1
+#define HAVE_STRCHR 1
+#define HAVE_STRERROR 1
+#define HAVE_STRSTR 1
+#define HAVE_TGAMMA 1
 #define SPT_TYPE SPT_REUSEARGV
 #define HAVE_SIGNBIT 1
+#define HAVE_FORK 1
+#define HAVE_VFORK 1
+#define HAVE_WORKING_VFORK 1
+#define HAVE_WORKING_FORK 1
 #define HAVE__LONGJMP 1
-#define HAVE__SETJMP 1
+#define HAVE_ATAN2L 1
+#define HAVE_ATAN2F 1
 #define HAVE_CHROOT 1
 #define HAVE_CLOCK_GETTIME 1
 #define HAVE_COSH 1
+#define HAVE_CRYPT_R 1
+#define HAVE_DIRFD 1
 #define HAVE_DL_ITERATE_PHDR 1
 #define HAVE_DLOPEN 1
+#define HAVE_DLADDR 1
 #define HAVE_DUP 1
 #define HAVE_DUP3 1
 #define HAVE_EACCESS 1
@@ -218,18 +250,22 @@
 #define HAVE_FCHOWN 1
 #define HAVE_FCNTL 1
 #define HAVE_FDATASYNC 1
+#define HAVE_FDOPENDIR 1
 #define HAVE_FMOD 1
-#define HAVE_FORK 1
+#define HAVE_FSTATAT 1
 #define HAVE_FSYNC 1
 #define HAVE_FTRUNCATE 1
 #define HAVE_FTRUNCATE64 1
 #define HAVE_GETCWD 1
+#define HAVE_GETGRNAM 1
 #define HAVE_GETGRNAM_R 1
 #define HAVE_GETGROUPS 1
 #define HAVE_GETPGID 1
 #define HAVE_GETPGRP 1
 #define HAVE_GETPRIORITY 1
 #define HAVE_GETPWNAM_R 1
+#define HAVE_GETRESGID 1
+#define HAVE_GETRESUID 1
 #define HAVE_GETRLIMIT 1
 #define HAVE_GETSID 1
 #define HAVE_GETTIMEOFDAY 1
@@ -243,19 +279,28 @@
 #define HAVE_LOCKF 1
 #define HAVE_LOG2 1
 #define HAVE_LSTAT 1
+#define HAVE_LUTIMES 1
 #define HAVE_MALLOC_USABLE_SIZE 1
 #define HAVE_MBLEN 1
 #define HAVE_MEMALIGN 1
+#define HAVE_WRITEV 1
 #define HAVE_MEMRCHR 1
+#define HAVE_MEMMEM 1
+#define HAVE_MKFIFO 1
+#define HAVE_MKNOD 1
 #define HAVE_MKTIME 1
+#define HAVE_OPENAT 1
 #define HAVE_PIPE2 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FADVISE 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PPOLL 1
 #define HAVE_PREAD 1
+#define HAVE_PWRITE 1
+#define HAVE_QSORT_R 1
 #define HAVE_READLINK 1
 #define HAVE_ROUND 1
+#define HAVE_SCHED_GETAFFINITY 1
 #define HAVE_SEEKDIR 1
 #define HAVE_SENDFILE 1
 #define HAVE_SETEGID 1
@@ -291,29 +336,37 @@
 #define HAVE_UTIMES 1
 #define HAVE_WAIT4 1
 #define HAVE_WAITPID 1
+#define HAVE_CRYPT_H 1
+#define HAVE_STRUCT_CRYPT_DATA_INITIALIZED 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP16 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP32 1
 #define HAVE_BUILTIN___BUILTIN_BSWAP64 1
+#define HAVE_BUILTIN___BUILTIN_POPCOUNT 1
+#define HAVE_BUILTIN___BUILTIN_POPCOUNTLL 1
 #define HAVE_BUILTIN___BUILTIN_CLZ 1
 #define HAVE_BUILTIN___BUILTIN_CLZL 1
 #define HAVE_BUILTIN___BUILTIN_CLZLL 1
+#define HAVE_BUILTIN___BUILTIN_CTZ 1
+#define HAVE_BUILTIN___BUILTIN_CTZLL 1
+#define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
+#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW_P 1
+#define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
+#define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
+#define HAVE_GNU_QSORT_R 1
+#define ATAN2_INF_C99 1
 #define HAVE_CLOCK_GETRES 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
 #define HAVE_DAYLIGHT 1
-#define HAVE_VAR_TIMEZONE 1
-#define TYPEOF_VAR_TIMEZONE long
-#define HAVE_TIMEZONE 1
-#define TIMEZONE_VOID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
+#define HAVE_SIG_T 1
 #define RSHIFT(x,y) ((x)>>(int)(y))
-#define FILE_READPTR _IO_read_ptr
-#define FILE_READEND _IO_read_end
-#define SIZEOF_STRUCT_STAT_ST_INO SIZEOF_LONG
 #define HAVE__SC_CLK_TCK 1
 #define STACK_GROW_DIRECTION -1
 #define _REENTRANT 1
@@ -321,15 +374,17 @@
 #define HAVE_LIBPTHREAD 1
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
-#define HAVE_PTHREAD_GETATTR_NP 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
+#define HAVE_PTHREAD_ATTR_INIT 1
 #define HAVE_PTHREAD_COND_INIT 1
 #define HAVE_PTHREAD_CONDATTR_SETCLOCK 1
 #define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SETNAME_NP 1
-#define HAVE_PTHREAD_ATTR_INIT 1
-#define SET_THREAD_NAME(name) pthread_setname_np(pthread_self(), name)
+#define HAVE_PTHREAD_GETATTR_NP 1
+#define SET_CURRENT_THREAD_NAME(name) pthread_setname_np(pthread_self(), name)
+#define SET_ANOTHER_THREAD_NAME(thid,name) pthread_setname_np(thid, name)
+#define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t *mc = &(uc)->uc_mcontext
 #define HAVE_GETCONTEXT 1
 #define HAVE_SETCONTEXT 1
 #define USE_ELF 1
@@ -338,10 +393,10 @@
 #define DLEXT_MAXLEN 3
 #define DLEXT ".so"
 #define LIBDIR_BASENAME "lib"
+#define HAVE__SETJMP 1
 #define RUBY_SETJMP(env) __builtin_setjmp((env))
 #define RUBY_LONGJMP(env,val) __builtin_longjmp((env),val)
 #define RUBY_JMP_BUF jmp_buf
 #define HAVE_PTHREAD_H 1
-#define HAVE_MEMMEM 1
 #define RUBY_PLATFORM "x86_64-linux"
 #endif /* INCLUDE_RUBY_CONFIG_H */
